==> firebase_ui-1.0.1.tar.gz: firebase_ui/src/Form/SendNotificationForm.php <==
<?php

namespace Drupal\firebase_ui\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Queue\QueueFactory;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\firebase_ui\Entity\FirebaseNotification;

/**
 * Provides a form to send Firebase push notifications.
 */
class SendNotificationForm extends FormBase implements ContainerInjectionInterface {

  /**
   * The queue factory service.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected $queue;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new SendNotificationForm.
   *
   * @param \Drupal\Core\Queue\QueueFactory $queue
   *   The queue factory.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $time
   *   The time service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(QueueFactory $queue, TimeInterface $time, EntityTypeManagerInterface $entity_type_manager) {
    $this->queue = $queue;
    $this->time = $time;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('queue'),
      $container->get('datetime.time'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'firebase_ui_send_notification_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Send To'),
      '#options' => [
        'all' => $this->t('All Users'),
        'specific_users' => $this->t('Specific Users'),
        'roles' => $this->t('Specific Roles'),
      ],
      '#default_value' => 'all',
      '#ajax' => [
        'callback' => '::updateTypeFields',
        'wrapper' => 'type-wrapper',
      ],
    ];

    $form['type_wrapper'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'type-wrapper'],
    ];

    if ($form_state->getValue('type') === 'specific_users') {
      $form['type_wrapper']['target_users'] = [
        '#type' => 'entity_autocomplete',
        '#title' => $this->t('Select Users'),
        '#target_type' => 'user',
        '#tags' => TRUE,
      ];
    }

    if ($form_state->getValue('type') === 'roles') {
      $form['type_wrapper']['roles'] = [
        '#type' => 'checkboxes',
        '#title' => $this->t('Select Roles'),
        '#options' => user_role_names(TRUE),
      ];
    }

    $form['schedule'] = [
      '#type' => 'radios',
      '#title' => $this->t('Send Time'),
      '#options' => [
        'now' => $this->t('Immediately'),
        'later' => $this->t('Schedule'),
      ],
      '#default_value' => 'now',
      '#ajax' => [
        'callback' => '::updateScheduleFields',
        'wrapper' => 'schedule-wrapper',
      ],
    ];

    $form['schedule_wrapper'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'schedule-wrapper'],
    ];

    if ($form_state->getValue('schedule') === 'later') {
      $form['schedule_wrapper']['send_time'] = [
        '#type' => 'datetime',
        '#title' => $this->t('Date & Time'),
        '#required' => TRUE,
      ];
    }

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Notification Title'),
      '#maxlength' => 50,
      '#required' => TRUE,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Notification Message'),
      '#maxlength' => 150,
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send Notification'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * AJAX callback for updating recipient fields based on selection.
   */
  public function updateTypeFields(array &$form, FormStateInterface $form_state) {
    return $form['type_wrapper'];
  }

  /**
   * AJAX callback for updating schedule date/time field.
   */
  public function updateScheduleFields(array &$form, FormStateInterface $form_state) {
    return $form['schedule_wrapper'];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $type = $form_state->getValue('type');
    $target_ids = '';

    if ($type === 'specific_users') {
      $target_ids = implode(',', [$form_state->getValue('target_users')]);
    }

    if ($type === 'roles') {
      $target_ids = implode(',', array_filter($form_state->getValue('roles')));
    }

    $send_time = ($form_state->getValue('schedule') === 'later') ?
      strtotime($form_state->getValue('send_time')->format('Y-m-d H:i:s')) :
      $this->time->getCurrentTime();

    $entity = FirebaseNotification::create([
      'type' => $type,
      'target_ids' => $target_ids,
      'title' => $form_state->getValue('title'),
      'message' => $form_state->getValue('message'),
      'send_time' => $send_time,
      'status' => TRUE,
    ]);

    $entity->save();

    $queue = $this->queue->get('firebase_ui_notification_queue');
    $queue->createItem(['nid' => $entity->id()]);

    $this->messenger()->addStatus($this->t('Notification queued.'));
  }

}

==> firebase_ui-1.0.3.tar.gz: firebase_ui/src/Form/SendNotificationForm.php <==
<?php

namespace Drupal\firebase_ui\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Queue\QueueFactory;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\firebase_ui\Entity\FirebaseNotification;

/**
 * Provides a form to send Firebase push notifications.
 */
class SendNotificationForm extends FormBase {

  /**
   * The queue factory service.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected $queue;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new SendNotificationForm.
   *
   * @param \Drupal\Core\Queue\QueueFactory $queue
   *   The queue factory.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $time
   *   The time service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(QueueFactory $queue, TimeInterface $time, EntityTypeManagerInterface $entity_type_manager) {
    $this->queue = $queue;
    $this->time = $time;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('queue'),
      $container->get('datetime.time'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'firebase_ui_send_notification_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Send To'),
      '#options' => [
        'all' => $this->t('All Users'),
        'specific_users' => $this->t('Specific Users'),
        'roles' => $this->t('Specific Roles'),
      ],
      '#default_value' => 'all',
      '#ajax' => [
        'callback' => '::updateTypeFields',
        'wrapper' => 'type-wrapper',
      ],
    ];

    $form['type_wrapper'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'type-wrapper'],
    ];

    if ($form_state->getValue('type') === 'specific_users') {
      $form['type_wrapper']['target_users'] = [
        '#type' => 'entity_autocomplete',
        '#title' => $this->t('Select Users'),
        '#target_type' => 'user',
        '#tags' => TRUE,
      ];
    }

    if ($form_state->getValue('type') === 'roles') {
      $form['type_wrapper']['roles'] = [
        '#type' => 'checkboxes',
        '#title' => $this->t('Select Roles'),
        '#options' => user_role_names(TRUE),
      ];
    }

    $form['schedule'] = [
      '#type' => 'radios',
      '#title' => $this->t('Send Time'),
      '#options' => [
        'now' => $this->t('Immediately'),
        'later' => $this->t('Schedule'),
      ],
      '#default_value' => 'now',
      '#ajax' => [
        'callback' => '::updateScheduleFields',
        'wrapper' => 'schedule-wrapper',
      ],
    ];

    $form['schedule_wrapper'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'schedule-wrapper'],
    ];

    if ($form_state->getValue('schedule') === 'later') {
      $form['schedule_wrapper']['send_time'] = [
        '#type' => 'datetime',
        '#title' => $this->t('Date & Time'),
        '#required' => TRUE,
      ];
    }

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Notification Title'),
      '#maxlength' => 50,
      '#required' => TRUE,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Notification Message'),
      '#maxlength' => 150,
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send Notification'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * AJAX callback for updating recipient fields based on selection.
   */
  public function updateTypeFields(array &$form, FormStateInterface $form_state) {
    return $form['type_wrapper'];
  }

  /**
   * AJAX callback for updating schedule date/time field.
   */
  public function updateScheduleFields(array &$form, FormStateInterface $form_state) {
    return $form['schedule_wrapper'];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $type = $form_state->getValue('type');
    $target_ids = '';

    if ($type === 'specific_users') {
      $target_ids = implode(',', [$form_state->getValue('target_users')]);
    }

    if ($type === 'roles') {
      $target_ids = implode(',', array_filter($form_state->getValue('roles')));
    }

    $send_time = ($form_state->getValue('schedule') === 'later') ?
      strtotime($form_state->getValue('send_time')->format('Y-m-d H:i:s')) :
      $this->time->getCurrentTime();

    $entity = FirebaseNotification::create([
      'type' => $type,
      'target_ids' => $target_ids,
      'title' => $form_state->getValue('title'),
      'message' => $form_state->getValue('message'),
      'send_time' => $send_time,
      'status' => TRUE,
    ]);

    $entity->save();

    $queue = $this->queue->get('firebase_ui_notification_queue');
    $queue->createItem(['nid' => $entity->id()]);

    $this->messenger()->addStatus($this->t('Notification queued.'));
  }

}
